@@ -3,7 +3,7 @@ from sqlalchemy import types
 from .exc import UnknownIdentityException
 
 
-trim = lambda a: a.strip()
+trim = lambda a: a and a.strip()
 
 
 def is_scalar(value):
